@@ -1,5 +1,6 @@
 """Templatetags for the ``document_library`` app."""
 from django import template
+from django.utils.translation import get_language
 
 from document_library.models import Document, DocumentTitle
 
@@ -9,9 +10,15 @@ register = template.Library()
 
 @register.assignment_tag
 def get_files_for_document(document):
-    """Returns all available files for the given document."""
+    """
+    Returns all available files for the given document in the current language.
+
+    """
+    lang = get_language()
+    if '-' in lang:
+        lang = lang.split('-')[0]
     titles = DocumentTitle.objects.filter(
-        document=document, filer_file__isnull=False)
+        document=document, filer_file__isnull=False, language=lang)
     files = [title.filer_file for title in titles]
     return files
 
